/*
 * $Id: bulletin_gui.h,v 1.11 2006/01/17 21:05:20 we7u Exp $
 *
 * XASTIR, Amateur Station Tracking and Information Reporting
 * Copyright (C) 1999,2000  Frank Giannandrea
 * Copyright (C) 2000-2006  The Xastir Group
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * Look at the README for more information on the program.
 */

#ifndef __XASTIR_BULLETIN_GUI_H
#define __XASTIR_BULLETIN_GUI_H

extern int bulletin_range;


// From bulletin_gui.c
extern void bulletin_gui_init(void);
extern void bulletin_data_add(char *call_sign, char *from_call, char *data, char *seq, char type, char from);
extern void check_for_new_bulletins(int current_sec);

#endif  // __XASTIR_BULLETIN_GUI_H


